/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {openToast} from 'frontend-js-web';

export default function ({
	getRedirectEntryChainCauseURL,
	initialDestinationURL,
	initialIsPermanent,
	namespace,
}) {
	const form = document[`${namespace}fm`];
	form.addEventListener('submit', saveRedirectEntry);
	const typeInfoAlert = document.getElementById(`${namespace}typeInfoAlert`);
	const destinationURLInput = document.getElementById(
		`${namespace}destinationURL`
	);
	const permanentSelect = document.getElementById(`${namespace}permanent`);

	if (typeInfoAlert && initialIsPermanent) {
		destinationURLInput.addEventListener('input', showTypeInfoAlert);
		permanentSelect.addEventListener('input', showTypeInfoAlert);
	}

	function showTypeInfoAlert() {
		typeInfoAlert.classList.toggle(
			'hide',
			permanentSelect.value === 'true' &&
				destinationURLInput.value === initialDestinationURL
		);
	}

	function saveRedirectEntry() {
		const destinationURL = form.elements[`${namespace}destinationURL`];
		const sourceURL = form.elements[`${namespace}sourceURL`];

		if (!sourceURL.value) {
			sourceURL.focus();
		}
		else if (
			!destinationURL.value ||
			destinationURL
				.closest('.form-group')
				.classList.contains('has-error')
		) {
			destinationURL.focus();
			destinationURL.blur();
		}
		else {
			Liferay.Util.fetch(
				Liferay.Util.PortletURL.createResourceURL(
					getRedirectEntryChainCauseURL,
					{
						destinationURL: destinationURL.value,
						sourceURL: sourceURL.value,
					}
				)
			)
				.then((response) => {
					return response.json();
				})
				.then((response) => {
					if (response.redirectEntryChainCause) {
						showModal(response.redirectEntryChainCause);
					}
					else {
						submitForm(form);
					}
				})
				.catch(() => {
					openToast({
						message: Liferay.Language.get(
							'an-unexpected-error-occurred'
						),
						type: 'danger',
					});
				});
		}
	}

	function showModal(redirectEntryChainCause) {
		Liferay.componentReady(`${namespace}RedirectsChainedRedirections`).then(
			(ChainedRedirections) => {
				ChainedRedirections.open(
					redirectEntryChainCause,
					(updateChainedRedirectEntries) => {
						Liferay.Util.postForm(form, {
							data: {
								updateChainedRedirectEntries,
							},
						});
					}
				);
			}
		);
	}
}
